@@ -46,66 +46,54 @@ def update_meta(self, other):
 
 class LateBindingProperty(property):
     """Property class that binds to getter/setter/deleter methods when **instance**
-of class that define the property is created. This allows you to override
-these methods in descendant classes (if they are not private) without
-necessity to redeclare the property itself in descendant class.
+    of class that define the property is created. This allows you to override
+    these methods in descendant classes (if they are not private) without
+    necessity to redeclare the property itself in descendant class.
 
-Recipe from Tim Delaney, 2005/03/31
-http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/408713
+    Recipe from Tim Delaney, 2005/03/31
+    http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/408713
 
-::
+    Example:
+        .. code-block:: python
 
-    class C(object):
+            class C(object):
+                def getx(self):
+                    print 'C.getx'
+                    return self._x
+                def setx(self, x):
+                    print 'C.setx'
+                    self._x = x
+                def delx(self):
+                    print 'C.delx'
+                    del self._x
+                x = LateBindingProperty(getx, setx, delx)
 
-        def getx(self):
-            print 'C.getx'
-            return self._x
+            class D(C):
+                def setx(self, x):
+                    print 'D.setx'
+                    super(D, self).setx(x)
+                def delx(self):
+                    print 'D.delx'
+                    super(D, self).delx()
 
-        def setx(self, x):
-            print 'C.setx'
-            self._x = x
+            c = C()
+            c.x = 1
+            c.x
+            c.x
+            del c.x
+            print
+            d = D()
+            d.x = 1
+            d.x
+            d.x
+            del d.x
 
-        def delx(self):
-            print 'C.delx'
-            del self._x
-
-        x = LateBindingProperty(getx, setx, delx)
-
-    class D(C):
-
-        def setx(self, x):
-            print 'D.setx'
-            super(D, self).setx(x)
-
-        def delx(self):
-            print 'D.delx'
-            super(D, self).delx()
-
-    c = C()
-    c.x = 1
-    c.x
-    c.x
-    del c.x
-
-    print
-
-    d = D()
-    d.x = 1
-    d.x
-    d.x
-    del d.x
-
-This has the advantages that:
-
-a. You get back an actual property object (with attendant memory savings, performance increases, etc);
-
-b. It's the same syntax as using property(fget, fset, fdel, doc) except for the name;
-
-c. It will fail earlier (when you define the class as opposed to when you use it).
-
-d. It's shorter ;)
-
-e. If you inspect the property you will get back functions with the correct __name__, __doc__, etc.
+    This has the advantages that:
+        - You get back an actual property object (with attendant memory savings, performance increases, etc);
+        - It's the same syntax as using property(fget, fset, fdel, doc) except for the name;
+        - It will fail earlier (when you define the class as opposed to when you use it).
+        - It's shorter ;)
+        - If you inspect the property you will get back functions with the correct `__name__`, `__doc__`, etc.
 
     """
     def __new__(cls, fget=None, fset=None, fdel=None, doc=None):
@@ -131,9 +119,9 @@ class Iterator(object):
     """
     def __init__(self, method, sentinel=None):
         """
-        :param method: Callable without parameters that returns next item.
-        :param sentinel: Value that when returned by `method` indicates the end
-                         of sequence.
+        Args:
+            method (callable): Callable without parameters that returns next item.
+            sentinel: Value that when returned by `method` indicates the end of sequence.
         """
         self.getnext = method
         self.sentinel = sentinel
@@ -193,31 +181,43 @@ class EmbeddedAttribute(property):
         setattr(getattr(obj, self.obj), self.attr, val)
 
 def iter_class_properties(cls):
-    """Iterator that yields `name, property` pairs for all properties in class.
+    """Iterator function.
 
-    :param class cls: Class object."""
+    Args:
+        cls (class): Class object.
+
+    Yields:
+        `name', 'property` pairs for all properties in class.
+"""
     for varname in vars(cls):
         value = getattr(cls, varname)
         if isinstance(value, property):
             yield varname, value
 
 def iter_class_variables(cls):
-    """Iterator that yields names of all non-callable attributes in class.
+    """Iterator function.
 
-    :param class cls: Class object."""
+    Args:
+        cls (class): Class object.
+
+    Yields:
+        Names of all non-callable attributes in class.
+"""
     for varname in vars(cls):
         value = getattr(cls, varname)
         if not (isinstance(value, property) or callable(value)) and not varname.startswith('_'):
             yield varname
 
 def embed_attributes(from_class, attr):
-    """Class decorator that injects properties and attributes
-from another class instance embedded in class instances. Only attributes and properties that are not
-already defined in decorated class are injected.
+    """Class decorator that injects properties and attributes from another class instance
+    embedded in class instances. Only attributes and properties that are not already defined
+    in decorated class are injected.
 
-    :param class from_class: Class that should extend decorated class.
-    :param string attr: Attribute name that holds instance of embedded class
-        within decorated class instance."""
+    Args:
+        from_class (class): Class that should extend decorated class.
+        attr (str): Attribute name that holds instance of embedded class within
+            decorated class instance.
+"""
     def d(class_):
         for pname, prop in iter_class_properties(from_class):
             if not hasattr(class_, pname):
@@ -245,11 +245,13 @@ class ObjectList(list):
 """
     def __init__(self, items=None, _cls=None, key_expr=None):
         """
-            :param iterable items: Sequence to initialize the collection.
-            :param _cls: Class or list/tuple of classes. Only instances of these classes would be allowed in collection.
-            :param str key_expr: Key expression. Must contain item referrence as `item`, for example `item.attribute_name`.
+        Args:
+            items (iterable): Sequence to initialize the collection.
+            _cls (class or list/tuple): Only instances of these class(es) would be allowed in collection.
+            key_expr (str): Key expression. Must contain item referrence as `item`, for example `item.attribute_name`.
 
-            :raises ValueError: When initialization sequence contains invalid instance.
+        Raises:
+            ValueError: When initialization sequence contains invalid instance.
             """
         if items:
             super(ObjectList, self).__init__(items)
@@ -281,42 +283,46 @@ class ObjectList(list):
     def insert(self, index, item):
         """Insert item before index.
 
-        :raises TypeError: When list is frozen or item is not an instance of allowed class"""
+        Raises:
+            TypeError: When list is frozen or item is not an instance of allowed class"""
         self.__check_mutability()
         self.__check_value(item)
         super(ObjectList, self).insert(index, item)
     def append(self, item):
         """Add an item to the end of the list.
 
-        :raises TypeError: When list is frozen or item is not an instance of allowed class"""
+        Raises:
+            TypeError: When list is frozen or item is not an instance of allowed class"""
         self.__check_mutability()
         self.__check_value(item)
         super(ObjectList, self).append(item)
     def extend(self, iterable):
         """Extend the list by appending all the items in the given iterable.
 
-        :raises TypeError: When list is frozen or item is not an instance of allowed class"""
+        Raises:
+            TypeError: When list is frozen or item is not an instance of allowed class"""
         for item in iterable:
             self.append(item)
     def sort(self, attrs=None, expr=None, reverse=False):
         """Sort items in-place, optionaly using attribute values as key or key expression.
 
-        :param list attrs: List of attribute names.
-        :param expr:       Key expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            attrs (list): List of attribute names.
+            expr: Key expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
         .. important::
 
-           Only one parameter (`attrs` or `expr`) could be specified. If none is present then uses default list sorting rule.
+           Only one parameter (`attrs` or `expr`) could be specified.
+           If none is present then uses default list sorting rule.
 
-        :raises TypeError: When list is frozen.
+        Examples:
+            .. code-block:: python
 
-        Examples::
-
-            sort(attrs=['name','degree'])       # Sort by item.name, item.degree
-            sort(expr=lambda x: x.name.upper()) # Sort by upper item.name
-            sort(expr='item.name.upper()')      # Sort by upper item.name
+                sort(attrs=['name','degree'])       # Sort by item.name, item.degree
+                sort(expr=lambda x: x.name.upper()) # Sort by upper item.name
+                sort(expr='item.name.upper()')      # Sort by upper item.name
     """
-        self.__check_mutability()
         if attrs:
             super(ObjectList, self).sort(key=attrgetter(*attrs), reverse=reverse)
         elif expr:
@@ -324,20 +330,24 @@ class ObjectList(list):
         else:
             super(ObjectList, self).sort(reverse=reverse)
     def reverse(self):
-        """Reverse the elements of the list, in place.
-
-        :raises TypeError: When list is frozen."""
-        self.__check_mutability()
+        """Reverse the elements of the list, in place."""
         super(ObjectList, self).reverse()
     def clear(self):
         """Remove all items from the list.
 
-        :raises TypeError: When list is frozen."""
+        Raises:
+            TypeError: When list is frozen."""
         self.__check_mutability()
         while len(self) > 0:
             del self[0]
     def freeze(self):
-        """Set list to immutable (frozen) state."""
+        """Set list to immutable (frozen) state.
+
+        Freezing list makes internal map from `key_expr` to item index that significantly
+        speeds up retrieval by key using the :meth:`get` method.
+
+        It's not possible to `add`, `delete` or `change` items in frozen list, but `sort` is allowed.
+"""
         self.__frozen = True
         if self.__key_expr:
             fce = make_lambda(self.__key_expr)
@@ -345,36 +355,45 @@ class ObjectList(list):
     def filter(self, expr):
         """Return new ObjectList of items for which `expr` is evaluated as True.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            filter(lambda x: x.name.startswith("ABC"))
-            filter('item.name.startswith("ABC")')
+                filter(lambda x: x.name.startswith("ABC"))
+                filter('item.name.startswith("ABC")')
 """
         fce = expr if callable(expr) else make_lambda(expr)
         return ObjectList(self.ifilter(expr), self._cls, self.__key_expr)
     def ifilter(self, expr):
         """Return generator that yields items for which `expr` is evaluated as True.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            ifilter(lambda x: x.name.startswith("ABC"))
-            ifilter('item.name.startswith("ABC")')
+                ifilter(lambda x: x.name.startswith("ABC"))
+                ifilter('item.name.startswith("ABC")')
 """
         fce = expr if callable(expr) else make_lambda(expr)
         return (item for item in self if fce(item))
     def ifilterfalse(self, expr):
         """Return generator that yields items for which `expr` is evaluated as False.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            ifilter(lambda x: x.name.startswith("ABC"))
-            ifilter('item.name.startswith("ABC")')
+                ifilter(lambda x: x.name.startswith("ABC"))
+                ifilter('item.name.startswith("ABC")')
 """
         fce = expr if callable(expr) else make_lambda(expr)
         return (item for item in self if not fce(item))
@@ -386,17 +405,18 @@ class ObjectList(list):
         - A callable accepting one parameter and returning data for output
         - One or more expressions as string referencing item as `item`.
 
-        Examples::
+        Examples:
+            .. code-block:: python
 
-            # returns list of tuples with item.name and item.size
+                # returns list of tuples with item.name and item.size
 
-            report(lambda x: (x.name, x.size))
-            report('item.name','item.size')
+                report(lambda x: (x.name, x.size))
+                report('item.name','item.size')
 
-            # returns list of item names
+                # returns list of item names
 
-            report(lambda x: x.name)
-            report('item.name')
+                report(lambda x: x.name)
+                report('item.name')
 """
         if len(args) == 1 and callable(args[0]):
             fce = args[0]
@@ -412,17 +432,18 @@ class ObjectList(list):
         - A callable accepting one parameter and returning data for output
         - One or more expressions as string referencing item as `item`.
 
-        Examples::
+        Examples:
+            .. code-block:: python
 
-            # generator of tuples with item.name and item.size
+                # generator of tuples with item.name and item.size
 
-            report(lambda x: (x.name, x.size))
-            report('item.name','item.size')
+                report(lambda x: (x.name, x.size))
+                report('item.name','item.size')
 
-            # generator of item names
+                # generator of item names
 
-            report(lambda x: x.name)
-            report('item.name')
+                report(lambda x: x.name)
+                report('item.name')
 """
         if len(args) == 1 and callable(args[0]):
             fce = args[0]
@@ -433,36 +454,47 @@ class ObjectList(list):
     def ecount(self, expr):
         """Return number of items for which `expr` is evaluated as True.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            ecount(lambda x: x.name.startswith("ABC"))
-            ecount('item.name.startswith("ABC")')
+                ecount(lambda x: x.name.startswith("ABC"))
+                ecount('item.name.startswith("ABC")')
 """
         return sum(1 for item in self.ifilter(expr))
     def split(self, expr):
-        """Return two new ObjectLists, first with items for which `expr` is evaluated as True and second for `expr` evaluated as False.
+        """Return two new ObjectLists, first with items for which `expr` is evaluated
+        as True and second for `expr` evaluated as False.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            split(lambda x: x.size > 100)
-            split('item.size > 100')
+                split(lambda x: x.size > 100)
+                split('item.size > 100')
 """
         return ObjectList(self.ifilter(expr), self._cls, self.__key_expr), ObjectList(self.ifilterfalse(expr), self._cls, self.__key_expr)
     def extract(self, expr):
         """Move items for which `expr` is evaluated as True into new ObjectLists.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        :raises TypeError: When list is frozen.
+        Raises:
+            TypeError: When list is frozen.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            extract(lambda x: x.name.startswith("ABC"))
-            extract('item.name.startswith("ABC")')
+                extract(lambda x: x.name.startswith("ABC"))
+                extract('item.name.startswith("ABC")')
 """
         self.__check_mutability()
         fce = expr if callable(expr) else make_lambda(expr)
@@ -477,23 +509,31 @@ class ObjectList(list):
                 i += 1
         return l
     def get(self, value, expr=None):
-        """Return item with given key value using default or specified key expression, or None if there is no such item.
+        """Return item with given key value using default or specified key expression,
+        or None if there is no such item.
 
-        Uses very fast method to look up value of default key expression in `frozen` list, otherwise it uses slower list traversal.
+        Uses very fast method to look up value of default key expression in `frozen` list,
+        otherwise it uses slower list traversal.
 
-        :param value:  Searched value.
-        :param expr:   Key value expression, a callable accepting two parameters (item,value) or expression as string referencing list item as `item`.
+        Args:
+            value: Searched value.
 
-        :raises TypeError: If key expression is not defined.
+        Keyword Args:
+            expr: Key value expression, a callable accepting two parameters (item,value)
+                  or expression as string referencing list item as `item`.
 
-        Examples::
+        Raises:
+            TypeError: If key expression is not defined.
 
-            # Search using default key expression
-            get('ITEM_NAME')
-            # Search using callable key expression
-            get('ITEM_NAME',lambda x: x.name.upper())
-            # Search using string key expression
-            get('ITEM_NAME','item.name.upper()')
+        Examples:
+            .. code-block:: python
+
+                # Search using default key expression
+                get('ITEM_NAME')
+                # Search using callable key expression
+                get('ITEM_NAME',lambda x: x.name.upper())
+                # Search using string key expression
+                get('ITEM_NAME','item.name.upper()')
 """
         if self.__map and not expr:
             i = self.__map.get(value)
@@ -512,28 +552,36 @@ class ObjectList(list):
     def contains(self, value, expr=None):
         """Return True if list has any item with default or specified key expression equal to given value.
 
-        :param value:  Tested key value.
-        :param expr:   Key value expression, a callable accepting two parameters (item,value) or expression as string referencing list item as `item`.
+        Args:
+            value: Tested key value.
 
-        Examples::
+        Keyword Args:
+            expr: Key value expression, a callable accepting two parameters (item,value)
+                  or expression as string referencing list item as `item`.
 
-            # Search using default key expression
-            contains('ITEM_NAME')
-            # Search using callable key expression
-            contains('ITEM_NAME',lambda x: x.name.upper())
-            # Search using string key expression
-            contains('ITEM_NAME','item.name.upper()')
+        Examples:
+            .. code-block:: python
+
+                # Search using default key expression
+                contains('ITEM_NAME')
+                # Search using callable key expression
+                contains('ITEM_NAME',lambda x: x.name.upper())
+                # Search using string key expression
+                contains('ITEM_NAME','item.name.upper()')
 """
         return False if self.get(value, expr) is None else True
     def all(self, expr):
         """Return True if `expr` is evaluated as True for all list elements.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            all(lambda x: x.name.startswith("ABC"))
-            all('item.name.startswith("ABC")')
+                all(lambda x: x.name.startswith("ABC"))
+                all('item.name.startswith("ABC")')
 """
         fce = expr if callable(expr) else make_lambda(expr)
         for item in self:
@@ -543,21 +591,25 @@ class ObjectList(list):
     def any(self, expr):
         """Return True if `expr` is evaluated as True for any list element.
 
-        :param expr:   Boolean expression, a callable accepting one parameter or expression as string referencing list item as `item`.
+        Args:
+            expr: Boolean expression, a callable accepting one parameter or expression
+                  as string referencing list item as `item`.
 
-        Example::
+        Example:
+            .. code-block:: python
 
-            any(lambda x: x.name.startswith("ABC"))
-            any('item.name.startswith("ABC")')
+                any(lambda x: x.name.startswith("ABC"))
+                any('item.name.startswith("ABC")')
 """
         fce = expr if callable(expr) else make_lambda(expr)
         for item in self:
-            if not fce(item):
+            if fce(item):
                 return True
         return False
     #
-    frozen = property(fget=lambda self: self.__frozen, doc='True if list is immutable')
+    frozen = property(fget=lambda self: self.__frozen, doc="True if list items couldn't be changed")
     key = property(fget=lambda self: self.__key_expr, doc='Key expression')
+    class_type = property(fget=lambda self: self._cls, doc='Class or list/tuple of classes that this list accepts.')
 
 class Visitable(object):
     """Base class for Visitor Pattern support.
@@ -567,7 +619,8 @@ class Visitable(object):
     def accept(self, visitor):
         """Visitor Pattern support. Calls `visit(self)` on parameter object.
 
-        :param visitor: Visitor object of Visitor Pattern.
+        Args:
+            visitor: Visitor object of Visitor Pattern.
         """
         visitor.visit(self)
 
@@ -584,8 +637,7 @@ class Visitor(object):
        This implementation uses Python Method Resolution Order (__mro__) to find special handling method, so special
        method for given class is used also for its decendants.
 
-    Example::
-
+    Example:
        class Node(object): pass
        class A(Node): pass
        class B(Node): pass
@@ -607,8 +659,7 @@ class Visitor(object):
        visitor.visit(b)
        visitor.visit(c)
 
-    Will create output::
-
+    Will create output:
        default_action A
        visit_B B
        visit_B C
@@ -619,7 +670,8 @@ class Visitor(object):
         First traverses the `obj.__mro__` to try find method with name following `visit_<class_name>` pattern and calls it with
         `obj`. Otherwise it calls :meth:`default_action`.
 
-        :param object obj: Object to be handled by visitor.
+        Args:
+            obj: Object to be handled by visitor.
 """
         meth = None
         for cls in obj.__class__.__mro__:
@@ -632,8 +684,10 @@ class Visitor(object):
     def default_action(self, obj):
         """Default handler for visited objects.
 
-        :param object obj: Object to be handled.
+        Args:
+            obj: Object to be handled.
 
-        .. note:: This implementation does nothing!
+        Note:
+            This implementation does nothing!
 """
         pass
